@@ -1,3 +1,5 @@
+/* $Id: countries.c,v 1.4 2003/02/22 23:12:40 d3august Exp $
+*/
 /*  xtraceroute - graphically show traceroute information.
  *  Copyright (C) 1996-1998  Bjrn Augustsson
  *
@@ -27,11 +29,13 @@
 
 const countrycode countries[] = 
 {
- {  38.53, -77.02, "gov", N_("US Government")},
- {  42.50,   1.53,  "ad", N_("Principalty of Andorra")},
- {  24.47,  54.37,  "ae", N_("United Arab Emirates")},
- {  34.35,  69.12,  "af", N_("Afghanistan")},
- {  17.00, -62.00,  "ag", N_("Antigua and Barbuda")},	/* approximative */
+ {  38.53, -77.02, "GOV", N_("US Government")},
+
+ {  -7.93, -14.37,  "AC", N_("Ascension Island")},
+ {  42.50,   1.53,  "AD", N_("Principalty of Andorra")},
+ {  24.47,  54.37,  "AE", N_("United Arab Emirates")},
+ {  34.35,  69.12,  "AF", N_("Afghanistan")},
+ {  17.00, -62.00,  "AG", N_("Antigua and Barbuda")},	/* approximative */
  {  18.00, -63.00,  "AI", N_("Anguilla")},		/* approximative */
  {  41.33,  19.82,  "AL", N_("Albania")},
  {  40.00,  44.00,  "AM", N_("Armenia")},
@@ -41,13 +45,13 @@ const countrycode countries[] =
  { -34.35, -58.29,  "AR", N_("Argentina")},
  { -14.50,-171.00,  "AS", N_("American Samoa")},	/* approximative */
  {  48.15,  16.22,  "AT", N_("Austria")},
- { -27.00, 133.00,  "au", N_("Australia")},
+ { -27.00, 133.00,  "AU", N_("Australia")},
  {  12.50, -70.00,  "AW", N_("Aruba")},			/* approximative */
  {  42.00,  45.00,  "AZ", N_("Azerbaijan")},
  {  43.87,  18.43,  "BA", N_("Bosnia and Herzegowina")},
  {  13.00, -59.00,  "BB", N_("Barbados")},		/* approximative */
  {  22.21,  91.50,  "BD", N_("Bangladesh")},
- {  50.83,   4.33,  "be", N_("Belgium")},
+ {  50.83,   4.33,  "BE", N_("Belgium")},
  {  12.33,  -1.67,  "BF", N_("Burkina Faso")},
  {  42.42,  23.20,  "BG", N_("Bulgaria")},
  {  26.02,  50.55,  "BH", N_("Bahrain")},
@@ -63,8 +67,9 @@ const countrycode countries[] =
  { -24.75,  25.92,  "BW", N_("Botswana")},
  {  53.54,  27.33,  "BY", N_("Belarus")},
  {  17.25, -88.78,  "BZ", N_("Belize")},
- {  45.4166, -75.7, "ca", N_("Canada")},
+ {  45.4166, -75.7, "CA", N_("Canada")},
  {   5.50, -87.00,  "CC", N_("Cocos Islands")},		/* approximative */
+ {  -4.33,  15.30,  "CD", N_("Congo, Democratic Republic of the")},
  {   4.38,  18.61,  "CF", N_("Central African Republic")},
  {   4.15,  15.15,  "CG", N_("Congo")},
  {  47.23,   8.33,  "CH", N_("Switzerland")},
@@ -72,7 +77,7 @@ const countrycode countries[] =
  { -15.00,-160.00,  "CK", N_("Cook Islands")},		/* approximative */
  { -33.27, -70.42,  "CL", N_("Chile")},
  {   3.85,  11.52,  "CM", N_("Cameroon")},
- {  39.917, 116.417, "cn", N_("China")},
+ {  39.917, 116.417, "CN", N_("China")},
  {   4.36, -74.05,  "CO", N_("Colombia")},
  {   9.95, -84.08,  "CR", N_("Costa Rica")},
  {  23.08, -82.21,  "CU", N_("Cuba")},
@@ -80,7 +85,7 @@ const countrycode countries[] =
  { -10.00, 105.00,  "CX", N_("Christmas Island")},	/* approximative */
  {  35.00,  33.00,  "CY", N_("Cyprus")},
  {  50.05,  14.25,  "CZ", N_("Czech Republic")},
- {  52.53,  13.42,  "de", N_("Germany")},
+ {  52.53,  13.42,  "DE", N_("Germany")},
  {  11.60,  43.15,  "DJ", N_("Djibouti")},
  {  55.41,  12.33,  "DK", N_("Denmark")},
  {  15.00, -62.00,  "DM", N_("Dominica")},		/* approximative */
@@ -93,17 +98,17 @@ const countrycode countries[] =
  {  15.00,  40.00,  "ER", N_("Eritrea")},		/* approximative */
  {  40.25,  -3.41,  "ES", N_("Spain")},
  {  15.02,  38.55,  "ET", N_("Ethiopia")},
- {  60.13,  25.00,  "fi", N_("Finland" )},
+ {  60.13,  25.00,  "FI", N_("Finland" )},
  { -17.00, 178.00,  "FJ", N_("Fiji")},			/* approximative */
  { -51.50, -60.00,  "FK", N_("Falkland Islands")},	/* approximative */
  {   5.00, 150.00,  "FM", N_("Micronesia")},		/* approximative */
  {  62.50,  -7.00,  "FO", N_("Faeroe Islands")},	/* approximative */
- {  48.87,   2.33,  "fr", N_("France")},
+ {  48.87,   2.33,  "FR", N_("France")},
  {   0.38,   9.42,  "GA", N_("Gabon")},
- {  51.50,   0.00,  "uk", N_("United Kingdom" )},
  {  12.00, -62.00,  "GD", N_("Grenada")},		/* approximative */
  {  41.43,  44.48,  "GE", N_("Georgia")},
  {   4.56, -52.27,  "GF", N_("French Guiana")},
+ {  49.45,  -2.53,  "GG", N_("Guernsey")},
  {   5.33,  -0.12,  "GH", N_("Ghana")},
  {  36.09,  -5.22,  "GI", N_("Gibraltar")},
  {  61.11, -45.25,  "GL", N_("Greenland")},
@@ -111,7 +116,7 @@ const countrycode countries[] =
  {   9.52, -13.72,  "GN", N_("Guinea")},
  {  16.00, -62.50,  "GP", N_("Guadaloupe")},		/* approximative */
  {   1.50, -10.00,  "GQ", N_("Equatorial Guinea")},	/* approximative */
- {   38.0,   23.73, "gr", N_("Greece" )},
+ {   38.0,   23.73, "GR", N_("Greece" )},
  { -59.00, -28.00,  "GS", N_("S. Georgia & Sandwich")},	/* approximative */
  {  14.06, -90.31,  "GT", N_("Guatemala")},
  {  14.00, 145.00,  "GU", N_("Guam")},			/* approximative */
@@ -126,12 +131,14 @@ const countrycode countries[] =
  {  -6.11, 106.50,  "ID", N_("Indonesia")},
  {  53.22,  -6.21,  "IE", N_("Ireland")},
  {  31.47,  35.13,  "IL", N_("Israel")},
+ {  54.27,  -4.50,  "IM", N_("Isle of Man")},
  {  28.35,  77.12,  "IN", N_("India")},
  {  -5.00,  75.00,  "IO", N_("British Indian Ocean Territory")}, /* approx. */
  {  33.20,  44.24,  "IQ", N_("Iraq")},
  {  35.41,  51.25,  "IR", N_("Iran")},
- {  64.15, -21.97,  "is", N_("Iceland" )},
+ {  64.15, -21.97,  "IS", N_("Iceland" )},
  {  41.48,  12.36,  "IT", N_("Italy")},
+ {  49.20,  -2.62,  "JE", N_("Jersey")},
  {  18.00, -76.75,  "JM", N_("Jamaica")},
  {  31.57,  35.57,  "JO", N_("Jordan, Hashemite Kingdom of")},
  {  35.75, 139.75,  "JP", N_("Japan")},
@@ -175,7 +182,7 @@ const countrycode countries[] =
  { -20.17,  57.50,  "MU", N_("Mauritius")},
  {   4.17,  73.50,  "MV", N_("Maldives, Republic of")},
  { -18.97,  33.82,  "MW", N_("Malawi, Republic of")},
- {  19.40, -99.15,  "mx", N_("Mexico")},
+ {  19.40, -99.15,  "MX", N_("Mexico")},
  {   3.07, 101.42,  "MY", N_("Malaysia")},
  { -25.97,  32.58,  "MZ", N_("Mozambique")},
  { -22.20,  17.10,  "NA", N_("Namibia")},		
@@ -185,7 +192,7 @@ const countrycode countries[] =
  {   6.27,   3.24,  "NG", N_("Nigeria, Federal Republic of")},
  {  12.10,  86.15,  "NI", N_("Nicaragua, Republic of")},
  {  52.35,   4.90,  "NL", N_("Netherlands, Kingdom of the")},
- {  59.93,  10.75,  "no", N_("Kingdom of Norway"  )},
+ {  59.93,  10.75,  "NO", N_("Kingdom of Norway"  )},
  {  27.42,  85.12,  "NP", N_("Nepal, Kingdom of")},
  {  -0.50, 166.50,  "NR", N_("Nauru, Republic of")},	/* approximative */
  { -19.00,-169.00,  "NU", N_("Niue")},
@@ -201,19 +208,20 @@ const countrycode countries[] =
  {  47.00, -56.50,  "PM", N_("St. Pierre et Miquelon")}, /* approximative */
  { -24.00,-130.00,  "PN", N_("Pitcairn Island")},	/* approximative */
  {  18.29, -66.07,  "PR", N_("Puerto Rico")},
+ {  31.78,  35.22,  "PS", N_("Palestinian Territories")},
  {  36.43,  -9.06,  "PT", N_("Portugal, Portuguese Republic")},
  {   8.00, 135.00,  "PW", N_("Palau")},			/* approximative */
  { -25.17, -57.30,  "PY", N_("Paraguay, Republic of")},
  {  25.03,  51.47,  "QA", N_("Qatar, State of")},
  { -22.00,  55.50,  "RE", N_("Reunion")},		/* approximative */
- {  44.43,  26.10,  "ro", N_("Romania")},
+ {  44.43,  26.10,  "RO", N_("Romania")},
  {  55.46,  37.40,  "RU", N_("Russian Federation")},
  {  -1.93,  30.07,  "RW", N_("Rwanda, Rwandese Republic")},
  {  24.39,  46.42,  "SA", N_("Saudi Arabia, Kingdom of")},
  {  -9.50, 160.00,  "SB", N_("Solomon Islands")},	/* approximative */
  {  -4.63,  55.47,  "SC", N_("Seychelles, Republic of")},
  {  15.37,  32.33,  "SD", N_("Sudan")},
- {  59.33,  18.08,  "se", N_("Kingdom of Sweden")},
+ {  59.33,  18.08,  "SE", N_("Kingdom of Sweden")},
  {   1.18, 103.50,  "SG", N_("Singapore, Republic of")},
  { -15.92,  18.17,  "SH", N_("St. Helena")},
  {  46.07,  14.50,  "SI", N_("Slovenia")},
@@ -246,6 +254,7 @@ const countrycode countries[] =
  {  -6.50,  39.18,  "TZ", N_("Tanzania, United Republic of")},
  {  50.27,  30.30,  "UA", N_("Ukraine")},
  {   0.33,  32.58,  "UG", N_("Uganda, Republic of")},
+ {  51.50,   0.00,  "UK", N_("United Kingdom" )},
  {   0.00,   0.00,  "UM", N_("US. Minor Outlying Islands")},
  {  38.53, -77.02,  "US", N_("United States of America")},
  { -34.51, -56.13,  "UY", N_("Uruguay, Eastern Republic of")},
@@ -262,7 +271,7 @@ const countrycode countries[] =
  {  13.00,  45.00,  "YE", N_("Yemen")},			/* approximative */
  { -12.00,  44.00,  "YT", N_("Mayotte")},		/* approximative */
  {  44.48,  20.28,  "YU", N_("Montenegro and Serbia")},
- { -33.93,  18.47,  "za", N_("Republic of South Africa" )},
+ { -33.93,  18.47,  "ZA", N_("Republic of South Africa" )},
  { -15.46,  28.26,  "ZM", N_("Zambia, Republic of")},
  {  -4.20,  15.18,  "ZR", N_("Zaire, Republic of")},
  { -17.83,  31.05,  "ZW", N_("Zimbabwe")}
